@@ -1,12 +1,5 @@
-#!/usr/bin/env perl
-use strict;
-use warnings;
-use utf8;
-use 5.010000;
-
-use Test::mysqld;
-
 $ENV{TEST_MYSQL} ||= do {
+    require Test::mysqld;
     my $mysqld = Test::mysqld->new(
         my_cnf => {
             'skip-networking' => '', # no TCP socket
